pub fn use_is_active() -> boolExpand description
Returns whether the closest ancestor ActivableContext provider is active.
Falls back to false when no provider is found in the tree.
pub fn use_is_active() -> boolReturns whether the closest ancestor ActivableContext provider is active.
Falls back to false when no provider is found in the tree.